==> jc-1.4.0.tar.gz: gnu/java/security/action/GetSecurityPropertyAction.h <==
// public class gnu.java.security.action.GetSecurityPropertyAction

// class file dependencies
// @dep_class fe524a92c03b0154 gnu_java_security_action_GetSecurityPropertyAction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_action_GetSecurityPropertyAction_H_
#define _JC_gnu_java_security_action_GetSecurityPropertyAction_H_

// Forward structure declarations
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_refs	_jc_gnu_java_security_action_GetSecurityPropertyAction$sub_refs;
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_nonrefs	_jc_gnu_java_security_action_GetSecurityPropertyAction$sub_nonrefs;
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$refs	_jc_gnu_java_security_action_GetSecurityPropertyAction$refs;
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$nonrefs	_jc_gnu_java_security_action_GetSecurityPropertyAction$nonrefs;
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object	_jc_gnu_java_security_action_GetSecurityPropertyAction$object;

typedef const struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vmethods	_jc_gnu_java_security_action_GetSecurityPropertyAction$vmethods;
typedef const struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vtable	_jc_gnu_java_security_action_GetSecurityPropertyAction$vtable;
typedef const struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vtype	_jc_gnu_java_security_action_GetSecurityPropertyAction$vtype;

// Constructors
extern void _jc_gnu_java_security_action_GetSecurityPropertyAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *);
extern void _jc_gnu_java_security_action_GetSecurityPropertyAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_security_action_GetSecurityPropertyAction$method$_init$a34354cd9552963f(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_action_GetSecurityPropertyAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *);
extern struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *_jc_gnu_java_security_action_GetSecurityPropertyAction$method$setParameters$089901d659b4500a(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *);
extern struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *_jc_gnu_java_security_action_GetSecurityPropertyAction$method$setParameters$a022995ad6e53cf0(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_action_GetSecurityPropertyAction$method_info$run$b190d7b16d5785b8;
extern _jc_method _jc_gnu_java_security_action_GetSecurityPropertyAction$method_info$setParameters$089901d659b4500a;
extern _jc_method _jc_gnu_java_security_action_GetSecurityPropertyAction$method_info$setParameters$a022995ad6e53cf0;

// Virtual methods structure
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *);
	struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object	*(*setParameters$089901d659b4500a)(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *);
	struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object	*(*setParameters$a022995ad6e53cf0)(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_action_GetSecurityPropertyAction$vmethods	gnu_java_security_action_GetSecurityPropertyAction;
};

// Vtype
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vtype {
	_jc_type			type;
	_jc_gnu_java_security_action_GetSecurityPropertyAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$refs {
    _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_refs	gnu_java_security_action_GetSecurityPropertyAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_nonrefs	gnu_java_security_action_GetSecurityPropertyAction;
};

// Object instance structure
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object {
	_jc_gnu_java_security_action_GetSecurityPropertyAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_action_GetSecurityPropertyAction$vtype	*vtype;
	_jc_gnu_java_security_action_GetSecurityPropertyAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_action_GetSecurityPropertyAction$vtype _jc_gnu_java_security_action_GetSecurityPropertyAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_action_GetSecurityPropertyAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_action_GetSecurityPropertyAction$class_object;

#endif	/* _JC_gnu_java_security_action_GetSecurityPropertyAction_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/action/GetSecurityPropertyAction.h <==
// public class gnu.java.security.action.GetSecurityPropertyAction

// class file dependencies
// @dep_class fe524a92c03b0154 gnu_java_security_action_GetSecurityPropertyAction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_action_GetSecurityPropertyAction_H_
#define _JC_gnu_java_security_action_GetSecurityPropertyAction_H_

// Forward structure declarations
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_refs	_jc_gnu_java_security_action_GetSecurityPropertyAction$sub_refs;
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_nonrefs	_jc_gnu_java_security_action_GetSecurityPropertyAction$sub_nonrefs;
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$refs	_jc_gnu_java_security_action_GetSecurityPropertyAction$refs;
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$nonrefs	_jc_gnu_java_security_action_GetSecurityPropertyAction$nonrefs;
typedef struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object	_jc_gnu_java_security_action_GetSecurityPropertyAction$object;

typedef const struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vmethods	_jc_gnu_java_security_action_GetSecurityPropertyAction$vmethods;
typedef const struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vtable	_jc_gnu_java_security_action_GetSecurityPropertyAction$vtable;
typedef const struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vtype	_jc_gnu_java_security_action_GetSecurityPropertyAction$vtype;

// Constructors
extern void _jc_gnu_java_security_action_GetSecurityPropertyAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_action_GetSecurityPropertyAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_action_GetSecurityPropertyAction$method$_init$a34354cd9552963f(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_action_GetSecurityPropertyAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *_jc_gnu_java_security_action_GetSecurityPropertyAction$method$setParameters$089901d659b4500a(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *_jc_gnu_java_security_action_GetSecurityPropertyAction$method$setParameters$a022995ad6e53cf0(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_action_GetSecurityPropertyAction$method_info$run$b190d7b16d5785b8;
extern _jc_method _jc_gnu_java_security_action_GetSecurityPropertyAction$method_info$setParameters$089901d659b4500a;
extern _jc_method _jc_gnu_java_security_action_GetSecurityPropertyAction$method_info$setParameters$a022995ad6e53cf0;

// Virtual methods structure
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object	*(*setParameters$089901d659b4500a)(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object	*(*setParameters$a022995ad6e53cf0)(_jc_env *, struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_action_GetSecurityPropertyAction$vmethods	gnu_java_security_action_GetSecurityPropertyAction;
};

// Vtype
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$vtype {
	_jc_type			type;
	_jc_gnu_java_security_action_GetSecurityPropertyAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$refs {
    _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_refs	gnu_java_security_action_GetSecurityPropertyAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_action_GetSecurityPropertyAction$sub_nonrefs	gnu_java_security_action_GetSecurityPropertyAction;
};

// Object instance structure
struct _jc_gnu_java_security_action_GetSecurityPropertyAction$object {
	_jc_gnu_java_security_action_GetSecurityPropertyAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_action_GetSecurityPropertyAction$vtype	*vtype;
	_jc_gnu_java_security_action_GetSecurityPropertyAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_action_GetSecurityPropertyAction$vtype _jc_gnu_java_security_action_GetSecurityPropertyAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_action_GetSecurityPropertyAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_action_GetSecurityPropertyAction$class_object;

#endif	/* _JC_gnu_java_security_action_GetSecurityPropertyAction_H_ */
